# LSB Test Execution Framework
# Apache test module
#
# Copyright (C) 2007-2008 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF with some parts
# derived from lsb-autotest written by Jiri Dluhos <jdluhos@suse.cz>
# Copyright (C) 2005-2007 SuSE Linux Products GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package Apache_test;
use strict;

use Common;
use Packages;

require Tests::Test_common;
@Apache_test::ISA = qw(Test_common);

=head ##
Class Apache_test Inherits Test_common;
=cut ##

sub new {
    my $self  = Test_common->new();
    $self->{NAME} = "apache";
    $self->{DISPLAYNAME} = "Apache Tests";
    $self->{DESCRIPTION} = "LSB Application Battery Functional Tests for Apache,"
        ." versatile, high-performance HTTP server.";
    $self->{PACKAGES} .= " lsb-apache";
    $self->{SOURCES} .= " appbat";
    $self->{BETA_SOURCES} .= " appbat";
    $self->{SNAPSHOT_SOURCES} .= " appbat";
    
    bless($self);
    return $self;
}

sub check {
    my $self = shift;
    my $result = "";
    my $checked = 0;
    
    # Check httpd is not running
    $result = check_port_80();
    if ( $result ) {
        # Try to stop
        stop_httpd();
        # Check again
        $result = check_port_80();
    }
    if ( $result ) {
        complain ( "Please, stop the process listening on the port 80." );
        complain ( "More info: $result" );
        return 0; # Failed
    }
    
    if ( !defined $result ) {
        complain_warn("Please, make sure that no one process is listening"
            ." on the port 80. If any, stop it.");
    }

    return Test_common::check($self);
}

sub check_port_80 {
    if ( does_shell_know ("netstat") ) {
        my $result = capture ("netstat -an 2>/dev/null | grep -e ':80 \\+[0-9:]'");
        if ( $result !~ /\busage:/) {
            my $result_ext = capture ("netstat -anp 2>/dev/null | grep -e ':80 \\+[0-9:]'");
            if ( $result_ext && ( $result_ext !~ /\busage:/ ) ) {
                $result = $result_ext;
            }
            return $result;
        } else { 
            return undef;
        }
    }
    return undef;
}

sub stop_httpd {
    my $process = '';
    for my $name ("apache", "apache2", "httpd", "lsb-apache") {
        if ( cmd("ps -A | grep -e '\\b$name\$'") == 0 ) {
            $process = $name;
            last;
        }
    }
    return unless $process;

    # Trying to stop httpd gracefully
    for my $script ($process, "apache", "apache2", "httpd", "lsb-apache") {
        if ( -f "/etc/init.d/$script" ) {
            inform("Stop http daemon");
            cmd("/etc/init.d/$script stop");
            sleep 2; # Wait a bit allowing apache to stop.
            
            last;
        }
    }

    # Kill the daemon if failed to stop it.
    if ( cmd("ps -A | grep -e '\\$process\$'") == 0 ) {
        cmd ("killall $process");
    }
}

# Run the test
sub run
{
    my $self = shift;
    
    my $http_started = 0;
    
    # Check httpd is not running
    stop_httpd();
   
    # Run the tests
    my $result = Test_common::run($self);

    stop_httpd();

    return $result;
}

sub journal {
    my $self = shift;
    
    # Parse the journal.
    store_journal_info(
        "Certification Tests/Automated Application Battery Tests/".$self->{DISPLAYNAME}
        , "apache", "$results_dir/test_journals/apache.simplejournal", $self);
}

1; # return value
