# LSB Test Execution Framework
# Runtime test module
#
# Copyright (C) 2007-2008 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF with some parts
# derived from lsb-autotest written by Jiri Dluhos <jdluhos@suse.cz>
# Copyright (C) 2005-2007 SuSE Linux Products GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package Runtime_test;
use strict;

use Common;
use Packages;

use Tests::Test_common;
@Runtime_test::ISA = qw(Test_common);

=head ##
Class Runtime_test Inherits Test_common;
=cut ##

sub new {
    my $self  = Test_common->new();
    $self->{NAME} = "core";
    $self->{DISPLAYNAME} = "Core Tests";
    $self->{DESCRIPTION} = "lsb-test-core is a test suite for testing"
        ." core interfaces for conformance to the LSB Specifications.";
    $self->{PACKAGES} .= " lsb-tet3 lsb-test-core";
    $self->{SOURCES} .= " runtime";
    $self->{BETA_SOURCES} .= " runtime";
    $self->{SNAPSHOT_SOURCES} .= " /snapshots/runtime-test /snapshots/tet-harness";

    bless($self);
    return $self;
}

sub run {
    my $self = shift;
    
    # Short scenario:
    my $path = package_file_location("lsb-test-core", "scen.exec");
    if ( $short_scenarios && -f "$path/scen.exec" ) {
        inform("Use short scenario");
        my $result = backup_and_replace( "$path/scen.exec",
            "$script_directory/Tests/runtime_short_scen" );
        if ( $result != 0 ) { inform ("The test will be skipped"); return 1; }
    }
    
    detach_loops();
    
    return Test_common::run($self);
}

sub journal {
    my $self = shift;
    
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/".$self->{DISPLAYNAME}
        , "runtime_test",
        "$results_dir/test_journals/runtime_test.journal", $self);
}

sub cleanup {
    my $self = shift;
    
    if ( $short_scenarios ) {
        my $scen_file = "/home/tet/test_sets/scen.exec";
        if ( -f "$scen_file.orig") {
            cmd ("cp -f $scen_file.orig $scen_file"); 
        }
    }
    
    detach_loops();
}

sub detach_loops {
    if ( does_shell_know("losetup") ) {
        if ( cmd("losetup -a >/dev/null 2>&1") == 0 ) {
            # If '-a' option is supported
            cmd ( "for loop in `losetup -a 2>/dev/null | grep -e 'loopback_disk.ext2' | sed s/:.*//`;"
                        ." do (umount \$loop; losetup -d \$loop;) 2>/dev/null; "
                    ."done" );
        } else {
            cmd ( "for i in `seq 0 9'; do"
                    ." losetup \"/dev/loop\$i\" 2>/dev/null | grep -e 'loopback_disk.ext2'"
                        ." && (umount \"/dev/loop\$i\"; losetup -d \"/dev/loop\$i\") 2>/dev/null; "
                ."done" );
        }
    }
}

1; # return value
